@@ -1,5 +1,6 @@
 import datetime
 import logging
+import codecs
 import os
 import sys
 import time
@@ -207,7 +208,9 @@ def main(
 ):
     """Moves your on-prem DS deployment to the cloud!"""
     sys.stdout = Logger()
+    sys.stdout = codecs.getwriter("utf8")(sys.stdout)
     sys.stderr = sys.stdout
+    sys.stderr = codecs.getwriter("utf8")(sys.stderr)
     OLD_API_KEY = original_api_key
     OLD_HOST = original_url
     NEW_API_KEY = cloud_one_api_key
