@@ -1,5 +1,6 @@
 import json
 import deepsecurity
+from deepsecurity.rest import ApiException
 import re
 import os
 
@@ -7,15 +8,10 @@ import os
 def to_snake(camel_case):
     pattern = re.compile(r"(?<!^)(?=[A-Z])")
     snake = pattern.sub("_", camel_case).lower()
+    snake = snake.replace("application_type_i_d", "application_type_id")
     return snake
 
 
-def to_class_name(snake_case):
-    temp = str(snake_case).split("_")
-    class_name = temp[0] + "".join(ele.title() for ele in temp)
-    return class_name
-
-
 class RestApiConfiguration:
     def __init__(
         self, NEW_API_KEY, NEW_HOST="https://cloudone.trendmicro.com", overrides=False
@@ -170,6 +166,33 @@ class FileListsApiInstance(RestApiConfiguration):
         return filelist.name
 
 
+class ApplicationTypesApiInstance(RestApiConfiguration):
+    def __init__(self, NEW_API_KEY, overrides=False):
+        RestApiConfiguration.__init__(self, NEW_API_KEY, overrides)
+        self.api_instance = deepsecurity.ApplicationTypesApi(self.api_client)
+
+    # def get(self, id):
+    #     return self.api_instance.describe_application_type(id, "v1")
+
+    def search(self, name):
+        filter = self.name_search_filter(name)
+        results = self.api_instance.search_application_types("v1", search_filter=filter)
+        if results.application_types:
+            return results.application_types[0].id
+
+    def create(self, json_application_types_list):
+        application_type = deepsecurity.ApplicationType()
+        for key in json_application_types_list:
+            if not key == "ID":
+                setattr(
+                    application_type,
+                    to_snake(key),
+                    json_application_types_list[key],
+                )
+        self.api_instance.create_application_type(application_type, self.api_version)
+        return application_type.name
+
+
 class AMConfigApiInstance(RestApiConfiguration):
     def __init__(self, NEW_API_KEY, overrides=False):
         RestApiConfiguration.__init__(self, NEW_API_KEY, overrides)
@@ -210,6 +233,27 @@ class FirewallApiInstance(RestApiConfiguration):
         return object.name
 
 
+class ApplicationControlRulesetsApiInstance(RestApiConfiguration):
+    def __init__(self, NEW_API_KEY, overrides=False):
+        RestApiConfiguration.__init__(self, NEW_API_KEY, overrides)
+        self.api_instance = deepsecurity.RulesetsApi(self.api_client)
+
+    def create(self, json, inventory_id):
+        ruleset = deepsecurity.Ruleset()
+        for key in json:
+            if not key == "ID":
+                setattr(ruleset, to_snake(key), json[key])
+        try:
+            self.api_instance.create_ruleset(ruleset, inventory_id, self.api_version)
+            return ruleset.name
+        except ApiException as e:
+            print(
+                "An exception occurred when calling RulesetsApi.create_ruleset: %s\n"
+                % e
+            )
+            pass
+
+
 class PolicyApiInstance(RestApiConfiguration):
     def __init__(self, NEW_API_KEY, overrides=False):
         RestApiConfiguration.__init__(self, NEW_API_KEY, overrides)
@@ -242,3 +286,71 @@ class PolicyApiInstance(RestApiConfiguration):
         self.api_instance.modify_policy(
             id, policy, self.api_version, overrides=self.overrides
         )
+
+
+class LogInspectionApiInstance(RestApiConfiguration):
+    def __init__(self, NEW_API_KEY, overrides=False):
+        RestApiConfiguration.__init__(self, NEW_API_KEY, overrides)
+        self.api_instance = deepsecurity.LogInspectionRulesApi(self.api_client)
+
+    def search(self, name):
+        filter = self.name_search_filter(name)
+        results = self.api_instance.search_log_inspection_rules(
+            "v1", search_filter=filter
+        )
+        if results.log_inspection_rules:
+            return results.log_inspection_rules[0].id
+
+    def create(self, json):
+        object = deepsecurity.LogInspectionRule()
+        for key in json:
+            if not key == "ID":
+                setattr(object, to_snake(key), json[key])
+        self.api_instance.create_log_inspection_rule(object, self.api_version)
+        return object.name
+
+
+class IntrusionPreventionApiInstance(RestApiConfiguration):
+    def __init__(self, NEW_API_KEY, overrides=False):
+        RestApiConfiguration.__init__(self, NEW_API_KEY, overrides)
+        self.api_instance = deepsecurity.IntrusionPreventionRulesApi(self.api_client)
+
+    def search(self, name):
+        filter = self.name_search_filter(name)
+        results = self.api_instance.search_intrusion_prevention_rules(
+            "v1", search_filter=filter
+        )
+        if results.intrusion_prevention_rules:
+            return results.intrusion_prevention_rules[0].id
+
+    def create(self, json):
+        object = deepsecurity.IntrusionPreventionRule()
+        for key in json:
+            if not key == "ID":
+                setattr(object, to_snake(key), json[key])
+        self.api_instance.create_intrusion_prevention_rule(object, self.api_version)
+        return object.name
+
+
+class IntegrityMonitoringApiInstance(RestApiConfiguration):
+    def __init__(self, NEW_API_KEY, overrides=False):
+        RestApiConfiguration.__init__(self, NEW_API_KEY, overrides)
+        self.api_instance = deepsecurity.IntegrityMonitoringRulesApi(self.api_client)
+
+    def search(self, name):
+        filter = self.name_search_filter(name)
+        results = self.api_instance.search_integrity_monitoring_rules(
+            "v1", search_filter=filter
+        )
+        if results.integrity_monitoring_rules:
+            return results.integrity_monitoring_rules[0].id
+
+    def create(self, json):
+        object = deepsecurity.IntegrityMonitoringRule()
+        for key in json:
+            if not key == "ID":
+                setattr(object, to_snake(key), json[key])
+        self.api_instance.create_integrity_monitoring_rule(
+            self.api_version, integrity_monitoring_rule=object
+        )
+        return object.name
